@@ -6,7 +6,7 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 
-our $VERSION = '0.0701';
+our $VERSION = '0.0702';
 
 use Algorithm::Combinatorics qw( combinations );
 use Math::Factor::XS qw( prime_factors );
@@ -383,7 +383,7 @@ Music::Intervals - Breakdown of musical intervals
 
 =head1 VERSION
 
-version 0.0701
+version 0.0702
 
 =head1 SYNOPSIS
 
@@ -419,11 +419,16 @@ version 0.0701
 
 =head1 DESCRIPTION
 
-A C<Music::Intervals> object shows the breakdown of musical notes, intervals and
-chords.
+A C<Music::Intervals> object shows the breakdown of musical notes,
+intervals and chords.
 
-This module reveals the "guts" within a given tonality.  And by guts I mean, the
-measurements of the notes and the intervals between them.
+This module reveals the "guts" within a given tonality.  And by guts I
+mean, the measurements of the notes and the intervals between them.
+
+For Western notes and intervals, this tonality begins with the C<C>
+note.  That is, all intervals are calculated from C<C>.  So, if you
+want to analyze a minor chord, either make it start on C<C> (like
+C<[C Eb G]>) or somewhere between C<C> and B<B> (like C<[D F A]>).
 
 =head1 ATTRIBUTES
 
